# eric7.EricWidgets.EricPlainTextDialog

Module implementing a dialog to show some plain text.

### Global Attributes

None

### Classes

EricPlainTextDialog | Class implementing a dialog to show some plain text.

### Functions

None

## EricPlainTextDialog

Class implementing a dialog to show some plain text.

### Derived from

QDialog, Ui_EricPlainTextDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricPlainTextDialog | Constructor
on_copyButton_clicked | Private slot to copy the text to the clipboard.

### Static Methods

None

#### EricPlainTextDialog (Constructor)

EricPlainTextDialog(title="", text="", parent=None)

Constructor

title (str)
  title of the window
text (str)
  text to be shown
parent (QWidget)
  reference to the parent widget

#### EricPlainTextDialog.on_copyButton_clicked

on_copyButton_clicked()

Private slot to copy the text to the clipboard.

Up